@@ -28,7 +28,7 @@ Defines the iPOPO decorators classes to manipulate component factory classes
 """
 
 # Module version
-__version_info__ = (0, 5, 0)
+__version_info__ = (0, 5, 2)
 __version__ = ".".join(map(str, __version_info__))
 
 # Documentation strings format
@@ -54,7 +54,7 @@ _logger = logging.getLogger("ipopo.decorators")
 
 # ------------------------------------------------------------------------------
 
-def is_from_parent(cls, attribute_name):
+def is_from_parent(cls, attribute_name, value=None):
     """
     Tests if the current attribute value is shared by a parent of the given
     class.
@@ -63,16 +63,22 @@ def is_from_parent(cls, attribute_name):
     
     :param cls: Child class with the requested attribute
     :param attribute_name: Name of the attribute to be tested
+    :param value: The exact value in the child class (optional)
     :return: True if the attribute value is shared with a parent class
     """
-    value = getattr(cls, attribute_name, None)
     if value is None:
-        # No need to go further
-        return False
+        # Get the current value
+        value = getattr(cls, attribute_name, None)
+        if value is None:
+            # No need to go further: the attribute does not exist
+            return False
 
     for base in cls.__bases__:
+        # Look for the value in each parent class
         base_value = getattr(base, attribute_name, None)
-        if base_value is value:
+        # Use '==' instead of 'is' to work in both
+        # Python 2 (==) and Python 3 (==, is)
+        if base_value == value:
             # Found !
             return True
 
@@ -170,6 +176,9 @@ def _get_factory_context(cls):
             # * Provided services
             del context.provides[:]
 
+            # * Manipulation has not been applied yet
+            context.completed = False
+
         # We have a context of our own, make sure we have a FactoryContext
         if isinstance(context, dict):
             # Already manipulated and stored class
@@ -197,7 +206,7 @@ def _ipopo_setup_callback(cls, context):
 
     functions = inspect.getmembers(cls, inspect.isroutine)
 
-    for name, function in functions:
+    for _, function in functions:
 
         if not hasattr(function, constants.IPOPO_METHOD_CALLBACKS):
             # No attribute, get the next member
@@ -207,8 +216,9 @@ def _ipopo_setup_callback(cls, context):
 
         if not isinstance(method_callbacks, list):
             # Invalid content
-            _logger.warning("Invalid attribute %s in %s", \
-                            constants.IPOPO_METHOD_CALLBACKS, name)
+            _logger.warning("Invalid callback information %s in %s", \
+                            constants.IPOPO_METHOD_CALLBACKS,
+                            get_method_description(function))
             continue
 
         # Keeping it allows inheritance : by removing it, only the first
@@ -217,12 +227,13 @@ def _ipopo_setup_callback(cls, context):
         # Store the call backs
         for _callback in method_callbacks:
             if _callback in callbacks and \
-            not is_from_parent(cls, callbacks[_callback].__name__):
-                _logger.warning("Redefining the callback %s in '%s'. " \
-                                "Previous callback : '%s' (%s). " \
-                                "New callback : %s", _callback, name,
-                                callbacks[_callback].__name__,
-                                callbacks[_callback], function)
+            not is_from_parent(cls, callbacks[_callback].__name__,
+                               callbacks[_callback]):
+                _logger.warning("Redefining the callback %s in class '%s'.\n" \
+                                "\tPrevious callback : %s\n" \
+                                "\tNew callback : %s", _callback, cls.__name__,
+                                get_method_description(callbacks[_callback]),
+                                get_method_description(function))
 
             callbacks[_callback] = function
 
@@ -466,37 +477,47 @@ class ComponentFactory:
         # Get the factory context
         context = _get_factory_context(factory_class)
 
-        # Set the factory name
-        if not self.__factory_name:
-            self.__factory_name = factory_class.__name__ + "Factory"
+        # Test if a manipulation has already been applied
+        if not context.completed:
+            # Set up the factory name
+            if not self.__factory_name:
+                self.__factory_name = factory_class.__name__ + "Factory"
 
-        context.name = self.__factory_name
+            # Manipulate the class...
+            context.name = self.__factory_name
+            context.completed = True
 
-        # Find callbacks
-        _ipopo_setup_callback(factory_class, context)
-        _ipopo_setup_field_callback(factory_class, context)
+            # Find callbacks
+            _ipopo_setup_callback(factory_class, context)
+            _ipopo_setup_field_callback(factory_class, context)
 
-        # Clean up inherited fields, to avoid weird behavior
-        for field in ComponentFactory.NON_INHERITABLE_FIELDS:
-            if is_from_parent(factory_class, field):
-                # Set inherited fields to None
-                setattr(factory_class, field, None)
+            # Clean up inherited fields, to avoid weird behavior
+            for field in ComponentFactory.NON_INHERITABLE_FIELDS:
+                if is_from_parent(factory_class, field):
+                    # Set inherited fields to None
+                    setattr(factory_class, field, None)
 
-        # Add the factory context field (set it to None)
-        setattr(factory_class, constants.IPOPO_FACTORY_CONTEXT, None)
+            # Add the factory context field (set it to None)
+            setattr(factory_class, constants.IPOPO_FACTORY_CONTEXT, None)
+
+            # Inject the properties getter and setter if needed
+            if len(context.properties_fields) > 0:
+                setattr(factory_class, constants.IPOPO_PROPERTY_PREFIX \
+                        + constants.IPOPO_GETTER_SUFFIX, None)
+                setattr(factory_class, constants.IPOPO_PROPERTY_PREFIX \
+                        + constants.IPOPO_SETTER_SUFFIX, None)
+
+        else:
+            # Manipulation already applied: do nothing more
+            _logger.error("%s has already been manipulated with the name '%s'. "
+                          "Keeping the old name.",
+                          get_method_description(factory_class), context.name)
 
         # Store a dictionary form of the factory context in the class
         # -> Avoids "class version" problems
         setattr(factory_class, constants.IPOPO_FACTORY_CONTEXT_DATA, \
                 context.to_dictionary_form())
 
-        # Inject the properties getter and setter if needed
-        if len(context.properties_fields) > 0:
-            setattr(factory_class, constants.IPOPO_PROPERTY_PREFIX \
-                    + constants.IPOPO_GETTER_SUFFIX, None)
-            setattr(factory_class, constants.IPOPO_PROPERTY_PREFIX \
-                    + constants.IPOPO_SETTER_SUFFIX, None)
-
         return factory_class
 
 # ------------------------------------------------------------------------------
@@ -557,6 +578,11 @@ class Property:
 
         # Get the factory context
         context = _get_factory_context(clazz)
+        if context.completed:
+            # Do nothing if the class has already been manipulated
+            _logger.warning("@Property: Already manipulated class: %s",
+                            get_method_description(clazz))
+            return clazz
 
         # Set up the property in the class
         context.properties[self.__name] = self.__value
@@ -659,6 +685,11 @@ class Provides:
 
         # Get the factory context
         context = _get_factory_context(clazz)
+        if context.completed:
+            # Do nothing if the class has already been manipulated
+            _logger.warning("@Provides: Already manipulated class: %s",
+                            get_method_description(clazz))
+            return clazz
 
         # Avoid duplicates (but keep the order)
         filtered_specs = []
@@ -735,6 +766,12 @@ class Requires:
 
         # Set up the property in the class
         context = _get_factory_context(clazz)
+        if context.completed:
+            # Do nothing if the class has already been manipulated
+            _logger.warning("@Requires: Already manipulated class: %s",
+                            get_method_description(clazz))
+            return clazz
+
         context.requirements[self.__field] = self.__requirement
 
         # Inject the field
