@@ -36,7 +36,7 @@ when using remote services on the local host only.
 """
 
 # Module version
-__version_info__ = (0, 1, 0)
+__version_info__ = (0, 1, 1)
 __version__ = ".".join(map(str, __version_info__))
 
 # Documentation strings format
@@ -626,6 +626,9 @@ class MulticastDiscovery(object):
             return
 
         try:
+            # Convert the response to a string
+            data = to_str(data)
+
             # Parse the JSON result
             return json.loads(data)
 
