@@ -34,7 +34,7 @@ A patched version of jsonrpclib will be released soon.
 """
 
 # Module version
-__version_info__ = (0, 1, 0)
+__version_info__ = (0, 1, 1)
 __version__ = ".".join(map(str, __version_info__))
 
 # Documentation strings format
@@ -49,6 +49,7 @@ from pelix.ipopo.decorators import ComponentFactory, Requires, Validate, \
 # Pelix constants
 import pelix.http
 import pelix.remote
+from pelix.utilities import to_str
 
 # Standard library
 import logging
@@ -105,7 +106,7 @@ class _JsonRpcServlet(SimpleJSONRPCDispatcher):
         """
         try:
             # Get the request content
-            data = request.read_data()
+            data = to_str(request.read_data())
 
             # Dispatch
             result = self._marshaled_dispatch(data, self._simple_dispatch)
