@@ -33,7 +33,7 @@ Based on standard package xmlrpclib
 """
 
 # Module version
-__version_info__ = (0, 1, 0)
+__version_info__ = (0, 1, 1)
 __version__ = ".".join(map(str, __version_info__))
 
 # Documentation strings format
@@ -48,6 +48,7 @@ from pelix.ipopo.decorators import ComponentFactory, Requires, Validate, \
 # Pelix constants
 import pelix.http
 import pelix.remote.beans
+from pelix.utilities import to_str
 
 # Standard library
 import logging
@@ -112,7 +113,7 @@ class _XmlRpcServlet(SimpleXMLRPCDispatcher):
         :param request: The HTTP response handler
         """
         # Get the request content
-        data = request.read_data()
+        data = to_str(request.read_data())
 
         # Dispatch
         result = self._marshaled_dispatch(data, self._simple_dispatch)
