@@ -30,7 +30,7 @@ Provides the basic command parsing and execution support to make a Pelix shell.
 """
 
 # Module version
-__version_info__ = (0, 2, 1)
+__version_info__ = (0, 2, 2)
 __version__ = ".".join(map(str, __version_info__))
 
 # Documentation strings format
@@ -203,6 +203,7 @@ class IOHandler(io.RawIOBase):
 
         # Write it
         self.write(line)
+        self.flush()
 
 
     def write_line_no_feed(self, line, *args, **kwargs):
@@ -223,6 +224,7 @@ class IOHandler(io.RawIOBase):
 
         # Write it
         self.write(line)
+        self.flush()
 
 # ------------------------------------------------------------------------------
 
@@ -599,7 +601,7 @@ class Shell(object):
 
         except ValueError as ex:
             # Unknown command
-            io_handler.write_line(ex.message)
+            io_handler.write_line(str(ex))
             return False
 
         # Get the content of the name space
@@ -638,7 +640,7 @@ class Shell(object):
         """
         Returns the Shell banner
         """
-        return "** Pelix Shell prompt **"
+        return "** Pelix Shell prompt **\n"
 
 
     def get_ps1(self):
@@ -837,7 +839,7 @@ class Shell(object):
 
             except ValueError as ex:
                 # Unknown command
-                io_handler.write_line(ex.message)
+                io_handler.write_line(str(ex))
                 return False
 
             else:
@@ -892,7 +894,7 @@ class Shell(object):
         property <name> - Prints the value of the given property, looking into
         framework properties then environment variables.
         """
-        io_handler.write_line(self._context.get_property(name))
+        io_handler.write_line(str(self._context.get_property(name)))
 
 
     def environment_list(self, io_handler):
